@@ -17,9 +17,8 @@
 #include "k3bjobprogressdialog.h"
 #include "k3bapplication.h"
 #include "k3bemptydiscwaiter.h"
-#include "k3bjobprogressosd.h"
 #include "k3bdebuggingoutputdialog.h"
-//#include "k3bjobinterface.h"
+#include "k3bjobinterface.h"
 #include "k3bthemedlabel.h"
 #include "k3b.h"
 #include "k3bjob.h"
@@ -27,36 +26,39 @@
 #include "k3bdevicemanager.h"
 #include "k3bdeviceglobals.h"
 #include "k3bglobals.h"
+#include "k3bkjobbridge.h"
 #include "k3bstdguiitems.h"
 #include "k3bversion.h"
 #include "k3bthememanager.h"
 
-#include <KColorScheme>
-#include <KConfig>
-#include <KDebug>
-#include <KGlobal>
-#include <KGlobalSettings>
-#include <KLocale>
-#include <KMessageBox>
-#include <KNotification>
-#include <KProgressDialog>
-#include <KPushButton>
-#include <KStandardGuiItem>
-#include <KSqueezedTextLabel>
+#include <KConfigWidgets/KColorScheme>
+#include <KConfigCore/KConfig>
+#include <KConfigCore/KSharedConfig>
+#include <KCoreAddons/KJobTrackerInterface>
+#include <KCoreAddons/KFormat>
+#include <KNotifications/KNotification>
+#include <KWidgetsAddons/KSqueezedTextLabel>
+#include <KI18n/KLocalizedString>
+#include <KIOCore/KIO/Global>
+#include <KWidgetsAddons/KMessageBox>
 
-#include <QCloseEvent>
-#include <QDateTime>
-#include <QFont>
-#include <QFrame>
-#include <QGridLayout>
-#include <QHBoxLayout>
-#include <QKeyEvent>
-#include <QLabel>
-#include <QPushButton>
-#include <QScrollBar>
-#include <QString>
-#include <QTreeWidget>
-#include <QVBoxLayout>
+#include <QtCore/QDebug>
+#include <QtCore/QDateTime>
+#include <QtCore/QString>
+#include <QtGui/QCloseEvent>
+#include <QtGui/QIcon>
+#include <QtGui/QFont>
+#include <QtGui/QKeyEvent>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QFrame>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QProgressBar>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QScrollBar>
+#include <QtWidgets/QTreeWidget>
+#include <QtWidgets/QVBoxLayout>
 
 
 class K3b::JobProgressDialog::Private
@@ -73,8 +75,7 @@ public:
 
 K3b::JobProgressDialog::JobProgressDialog( QWidget* parent,
                                            bool showSubProgress )
-    : KDialog( parent ),
-      m_osd(0)
+    : QDialog( parent )
 {
     d = new Private;
     setupGUI();
@@ -92,32 +93,32 @@ K3b::JobProgressDialog::JobProgressDialog( QWidget* parent,
  */
 K3b::JobProgressDialog::~JobProgressDialog()
 {
-    kDebug();
+    qDebug();
     delete d;
-    delete m_osd;
 }
 
 
 void K3b::JobProgressDialog::setupGUI()
 {
-    // KDialog does not allow to use Cancel and Close buttons at the same time!
-    setButtons( KDialog::Cancel|KDialog::User1|KDialog::User2 );
-    setButtonText( User1, i18n("Show Debugging Output") );
-    setButtonGuiItem( User2, KStandardGuiItem::close() );
-
-    QVBoxLayout* mainLayout = new QVBoxLayout( mainWidget() );
-    mainLayout->setMargin( 0 );
+    QVBoxLayout* mainLayout = new QVBoxLayout( this );
 
     // header
     // ------------------------------------------------------------------------------------------
-    d->headerFrame = new QFrame( mainWidget() );
-    d->headerFrame->setFrameShape( QFrame::StyledPanel );
-    d->headerFrame->setFrameShadow( QFrame::Sunken );
-    d->headerFrame->setLineWidth( 1 );
+    QFrame* headerParentFrame = new QFrame( this );
+    headerParentFrame->setFrameShape( QFrame::StyledPanel );
+    headerParentFrame->setFrameShadow( QFrame::Sunken );
+    headerParentFrame->setLineWidth( 1 );
+    headerParentFrame->setLayout( new QVBoxLayout() );
+    headerParentFrame->layout()->setSpacing(0);
+    headerParentFrame->layout()->setMargin(0);
+
+    d->headerFrame = new QFrame( headerParentFrame );
+    d->headerFrame->setFrameStyle( QFrame::NoFrame );
     d->headerFrame->setAutoFillBackground( true );
-    //d->headerFrame->setMargin( 1 );
+    headerParentFrame->layout()->addWidget( d->headerFrame );
+
     QHBoxLayout* headerLayout = new QHBoxLayout( d->headerFrame );
-    headerLayout->setMargin( 0 );
+    headerLayout->setContentsMargins( 0, 0, 0, 0 );
     headerLayout->setSpacing( 0 );
     m_pixLabel = new K3b::ThemedLabel( d->headerFrame );
     headerLayout->addWidget( m_pixLabel );
@@ -141,10 +142,10 @@ void K3b::JobProgressDialog::setupGUI()
     headerLayout->addLayout( jobLabelsLayout );
     headerLayout->setAlignment( jobLabelsLayout, Qt::AlignVCenter );
 
-    mainLayout->addWidget( d->headerFrame );
+    mainLayout->addWidget( headerParentFrame );
     // ------------------------------------------------------------------------------------------
 
-    d->viewInfo = new QTreeWidget( mainWidget() );
+    d->viewInfo = new QTreeWidget( this );
     d->viewInfo->setAllColumnsShowFocus( true );
     d->viewInfo->setHeaderHidden( true );
     d->viewInfo->setSortingEnabled( false );
@@ -156,14 +157,21 @@ void K3b::JobProgressDialog::setupGUI()
 
     // progress header
     // ------------------------------------------------------------------------------------------
-    d->progressHeaderFrame = new QFrame( mainWidget() );
-    d->progressHeaderFrame->setFrameShape( QFrame::StyledPanel );
-    d->progressHeaderFrame->setFrameShadow( QFrame::Sunken );
-    d->progressHeaderFrame->setLineWidth( 1 );
+    QFrame* progressHeaderParentFrame = new QFrame( this );
+    progressHeaderParentFrame->setFrameShape( QFrame::StyledPanel );
+    progressHeaderParentFrame->setFrameShadow( QFrame::Sunken );
+    progressHeaderParentFrame->setLineWidth( 1 );
+    progressHeaderParentFrame->setLayout( new QVBoxLayout() );
+    progressHeaderParentFrame->layout()->setSpacing(0);
+    progressHeaderParentFrame->layout()->setMargin(0);
+
+    d->progressHeaderFrame = new QFrame( progressHeaderParentFrame );
+    d->progressHeaderFrame->setFrameStyle( QFrame::NoFrame );
     d->progressHeaderFrame->setAutoFillBackground( true );
+    progressHeaderParentFrame->layout()->addWidget( d->progressHeaderFrame );
 
     QHBoxLayout* progressHeaderLayout = new QHBoxLayout( d->progressHeaderFrame );
-    progressHeaderLayout->setMargin( 0 );
+    progressHeaderLayout->setContentsMargins( 0, 0, 0, 0 );
     progressHeaderLayout->setSpacing( 0 );
 
     m_labelTask = new K3b::ThemedLabel( d->progressHeaderFrame );
@@ -184,51 +192,63 @@ void K3b::JobProgressDialog::setupGUI()
     progressHeaderLayout->addLayout( jobProgressLayout );
     progressHeaderLayout->setAlignment( jobProgressLayout, Qt::AlignVCenter );
     progressHeaderLayout->addWidget( new K3b::ThemedLabel( K3b::Theme::PROGRESS_RIGHT, d->progressHeaderFrame ) );
-    mainLayout->addWidget( d->progressHeaderFrame );
+    mainLayout->addWidget( progressHeaderParentFrame );
     // ------------------------------------------------------------------------------------------
 
     QHBoxLayout* layout3 = new QHBoxLayout;
 
-    m_labelSubTask = new KSqueezedTextLabel( mainWidget() );
+    m_labelSubTask = new KSqueezedTextLabel( this );
     m_labelSubTask->setTextElideMode( Qt::ElideRight );
     layout3->addWidget( m_labelSubTask );
 
-    m_labelSubProcessedSize = new QLabel( mainWidget() );
+    m_labelSubProcessedSize = new QLabel( this );
     m_labelSubProcessedSize->setAlignment( Qt::AlignVCenter | Qt::AlignRight );
     layout3->addWidget( m_labelSubProcessedSize );
     mainLayout->addLayout( layout3 );
 
-    m_progressSubPercent = new QProgressBar( mainWidget() );
+    m_progressSubPercent = new QProgressBar( this );
     mainLayout->addWidget( m_progressSubPercent );
 
     QHBoxLayout* layout4 = new QHBoxLayout;
 
-    QLabel* textLabel5 = new QLabel( i18n("Overall progress:"), mainWidget() );
+    QLabel* textLabel5 = new QLabel( i18n("Overall progress:"), this );
     layout4->addWidget( textLabel5 );
 
-    m_labelProcessedSize = new QLabel( mainWidget() );
+    m_labelProcessedSize = new QLabel( this );
     m_labelProcessedSize->setAlignment( Qt::AlignVCenter | Qt::AlignRight );
     layout4->addWidget( m_labelProcessedSize );
     mainLayout->addLayout( layout4 );
 
-    m_progressPercent = new QProgressBar( mainWidget() );
+    m_progressPercent = new QProgressBar( this );
     mainLayout->addWidget( m_progressPercent );
 
-    m_frameExtraInfo = new QFrame( mainWidget() );
+    m_frameExtraInfo = new QFrame( this );
     m_frameExtraInfo->setFrameShape( QFrame::NoFrame );
     m_frameExtraInfo->setFrameShadow( QFrame::Raised );
     m_frameExtraInfoLayout = new QGridLayout( m_frameExtraInfo );
-    m_frameExtraInfoLayout->setMargin(0);
+    m_frameExtraInfoLayout->setContentsMargins( 0, 0, 0,0 );
     mainLayout->addWidget( m_frameExtraInfo );
 
+    QDialogButtonBox* buttonBox = new QDialogButtonBox( this );
+    m_cancelButton = buttonBox->addButton( QDialogButtonBox::Cancel );
+    connect( m_cancelButton, SIGNAL(clicked()), this, SLOT(reject()) );
+
+    m_showDbgOutButton = buttonBox->addButton( i18n("Show Debugging Output"), QDialogButtonBox::NoRole );
+    connect( m_showDbgOutButton, SIGNAL(clicked()), this, SLOT(slotShowDebuggingOutput()) );
+
+    m_closeButton = buttonBox->addButton( QDialogButtonBox::Close );
+    connect( m_closeButton, SIGNAL(clicked()), this, SLOT(accept()) );
+
+    mainLayout->addWidget( buttonBox );
+
     m_pixLabel->setThemePixmap( K3b::Theme::PROGRESS_WORKING );
 
     slotThemeChanged();
 
-    connect( k3bappcore->themeManager(), SIGNAL(themeChanged()),
-             this, SLOT(slotThemeChanged()) );
-    connect( KGlobalSettings::self(), SIGNAL(appearanceChanged()),
-             this, SLOT(slotThemeChanged()) );
+    if (k3bappcore) {
+        connect( k3bappcore->themeManager(), SIGNAL(themeChanged()),
+                 this, SLOT(slotThemeChanged()) );
+    }
 }
 
 
@@ -239,35 +259,34 @@ void K3b::JobProgressDialog::setExtraInfo( QWidget *extra )
 }
 
 
+bool K3b::JobProgressDialog::event( QEvent *event )
+{
+    if( event->type() == QEvent::StyleChange ) {
+        slotThemeChanged();
+    }
+    return QDialog::event( event );
+}
+
+
 void K3b::JobProgressDialog::showEvent( QShowEvent* e )
 {
     if( !e->spontaneous() ) {
-        if( KConfigGroup( KGlobal::config(), "General Options" ).readEntry( "hide main window while writing", false ) ) {
+        if( KConfigGroup( KSharedConfig::openConfig(), "General Options" ).readEntry( "hide main window while writing", false ) ) {
             k3bappcore->k3bMainWindow()->hide();
         }
-
-        if( m_osd ) {
-            m_osd->readSettings( KGlobal::config()->group( "OSD Position" ) );
-            m_osd->show();
-        }
     }
-    KDialog::showEvent( e );
+    QDialog::showEvent( e );
 }
 
 
 void K3b::JobProgressDialog::closeEvent( QCloseEvent* e )
 {
-    if( button( User2 )->isVisible() ) {
-        KDialog::closeEvent( e );
+    if( m_closeButton->isVisible() ) {
+        QDialog::closeEvent( e );
         k3bappcore->k3bMainWindow()->show();
 
         if( !m_plainCaption.isEmpty() )
             k3bappcore->k3bMainWindow()->setPlainCaption( m_plainCaption );
-
-        if( m_osd ) {
-            m_osd->hide();
-            m_osd->saveSettings( KGlobal::config()->group( "OSD Position" ) );
-        }
     }
     else
         e->ignore();
@@ -276,45 +295,45 @@ void K3b::JobProgressDialog::closeEvent( QCloseEvent* e )
 
 void K3b::JobProgressDialog::slotProcessedSize( int processed, int size )
 {
-#if KDE_IS_VERSION( 4, 3, 80 )
-    m_labelProcessedSize->setText( i18nc( "%1 and %2 are byte sizes formatted via KLocale::formatByteSize",
+//#if KDE_IS_VERSION( 4, 3, 80 )
+    m_labelProcessedSize->setText( i18nc( "%1 and %2 are byte sizes formatted via KFormat::formatByteSize",
                                           "%1 of %2",
-                                          KGlobal::locale()->formatByteSize( ( double )( ( qulonglong )processed*1024ULL*1024ULL ),
-                                                                             1,
-                                                                             KLocale::DefaultBinaryDialect,
-                                                                             KLocale::UnitMegaByte ),
-                                          KGlobal::locale()->formatByteSize( ( double )( ( qulonglong )size*1024ULL*1024ULL ),
-                                                                             1,
-                                                                             KLocale::DefaultBinaryDialect,
-                                                                             KLocale::UnitMegaByte ) ) );
-#else
-    m_labelProcessedSize->setText( i18nc( "%1 and %2 are byte sizes formatted via KLocale::formatByteSize",
-                                          "%1 of %2",
-                                          KGlobal::locale()->formatByteSize( ( double )( ( qulonglong )processed*1024ULL*1024ULL ) ),
-                                          KGlobal::locale()->formatByteSize( ( double )( ( qulonglong )size*1024ULL*1024ULL ) ) ) );
-#endif
+                                          KFormat().formatByteSize( ( double )( ( qulonglong )processed*1024ULL*1024ULL ),
+                                                                    1,
+                                                                    KFormat::DefaultBinaryDialect,
+                                                                    KFormat::UnitMegaByte ),
+                                          KFormat().formatByteSize( ( double )( ( qulonglong )size*1024ULL*1024ULL ),
+                                                                    1,
+                                                                    KFormat::DefaultBinaryDialect,
+                                                                    KFormat::UnitMegaByte ) ) );
+//#else
+//    m_labelProcessedSize->setText( i18nc( "%1 and %2 are byte sizes formatted via KFormat::formatByteSize",
+//                                          "%1 of %2",
+//                                          KFormat().formatByteSize( ( double )( ( qulonglong )processed*1024ULL*1024ULL ) ),
+//                                          KFormat().formatByteSize( ( double )( ( qulonglong )size*1024ULL*1024ULL ) ) ) );
+//#endif
 }
 
 
 void K3b::JobProgressDialog::slotProcessedSubSize( int processedTrackSize, int trackSize )
 {
-#if KDE_IS_VERSION( 4, 3, 80 )
-    m_labelSubProcessedSize->setText( i18nc( "%1 and %2 are byte sizes formatted via KLocale::formatByteSize",
+//#if KDE_IS_VERSION( 4, 3, 80 )
+    m_labelSubProcessedSize->setText( i18nc( "%1 and %2 are byte sizes formatted via KFormat::formatByteSize",
                                              "%1 of %2",
-                                             KGlobal::locale()->formatByteSize( ( double )( ( qulonglong )processedTrackSize*1024ULL*1024ULL ),
-                                                                                1,
-                                                                                KLocale::DefaultBinaryDialect,
-                                                                                KLocale::UnitMegaByte ),
-                                             KGlobal::locale()->formatByteSize( ( double )( ( qulonglong )trackSize*1024ULL*1024ULL ),
-                                                                                1,
-                                                                                KLocale::DefaultBinaryDialect,
-                                                                                KLocale::UnitMegaByte ) ) );
-#else
-    m_labelSubProcessedSize->setText( i18nc( "%1 and %2 are byte sizes formatted via KLocale::formatByteSize",
-                                             "%1 of %2",
-                                             KGlobal::locale()->formatByteSize( ( double )( ( qulonglong )processedTrackSize*1024ULL*1024ULL ) ),
-                                             KGlobal::locale()->formatByteSize( ( double )( ( qulonglong )trackSize*1024ULL*1024ULL ) ) ) );
-#endif
+                                             KFormat().formatByteSize( ( double )( ( qulonglong )processedTrackSize*1024ULL*1024ULL ),
+                                                                       1,
+                                                                       KFormat::DefaultBinaryDialect,
+                                                                       KFormat::UnitMegaByte ),
+                                             KFormat().formatByteSize( ( double )( ( qulonglong )trackSize*1024ULL*1024ULL ),
+                                                                       1,
+                                                                       KFormat::DefaultBinaryDialect,
+                                                                       KFormat::UnitMegaByte ) ) );
+//#else
+//    m_labelSubProcessedSize->setText( i18nc( "%1 and %2 are byte sizes formatted via KFormat::formatByteSize",
+//                                             "%1 of %2",
+//                                             KFormat().formatByteSize( ( double )( ( qulonglong )processedTrackSize*1024ULL*1024ULL ) ),
+//                                             KFormat().formatByteSize( ( double )( ( qulonglong )trackSize*1024ULL*1024ULL ) ) ) );
+//#endif
 }
 
 
@@ -326,17 +345,17 @@ void K3b::JobProgressDialog::slotInfoMessage( const QString& infoString, int typ
     // set the icon
     switch( type ) {
     case K3b::Job::MessageError:
-        currentInfoItem->setIcon( 0, KIcon( "dialog-error" ) );
+        currentInfoItem->setIcon( 0, QIcon::fromTheme( "dialog-error" ) );
         break;
     case K3b::Job::MessageWarning:
-        currentInfoItem->setIcon( 0, KIcon( "dialog-warning" ) );
+        currentInfoItem->setIcon( 0, QIcon::fromTheme( "dialog-warning" ) );
         break;
     case K3b::Job::MessageSuccess:
-        currentInfoItem->setIcon( 0, KIcon( "dialog-ok" ) );
+        currentInfoItem->setIcon( 0, QIcon::fromTheme( "dialog-ok" ) );
         break;
     case K3b::Job::MessageInfo:
     default:
-        currentInfoItem->setIcon( 0, KIcon( "dialog-information" ) );
+        currentInfoItem->setIcon( 0, QIcon::fromTheme( "dialog-information" ) );
     }
 
     d->viewInfo->scrollToItem( currentInfoItem, QAbstractItemView::EnsureVisible );
@@ -345,7 +364,7 @@ void K3b::JobProgressDialog::slotInfoMessage( const QString& infoString, int typ
 
 void K3b::JobProgressDialog::slotFinished( bool success )
 {
-    kDebug() << "received finished signal!";
+    qDebug() << "received finished signal!";
 
     m_logFile.close();
 
@@ -355,8 +374,8 @@ void K3b::JobProgressDialog::slotFinished( bool success )
     // Only show elapsed time at the end of the task
     // setVisible( false ) would move elapsed time one line up ...
     m_labelRemainingTime->setText( "" );
-    m_labelElapsedTime->setText( i18nc( "@info %1 is a duration formatted using KLocale::prettyFormatDuration",
-        "Elapsed time: %1", KGlobal::locale()->prettyFormatDuration( m_timer.elapsed() ) ) );
+    m_labelElapsedTime->setText( i18nc( "@info %1 is a duration formatted using QLocale::toString",
+        "Elapsed time: %1", QLocale().toString( QTime().addSecs( m_timer.elapsed() ), QLocale::NarrowFormat ) ) );
     m_timer.invalidate();
 
     if( success ) {
@@ -372,10 +391,7 @@ void K3b::JobProgressDialog::slotFinished( bool success )
         m_progressSubPercent->setValue(100);
         slotProgress(100);
 
-        if( m_osd )
-            m_osd->setText( i18n("Success.") );
-
-        KNotification::event("SuccessfullyFinished", i18n("Successfully finished."), QPixmap(), 0);
+        KNotification::event("SuccessfullyFinished", i18n("Successfully finished."));
     }
     else {
         m_pixLabel->setThemePixmap( K3b::Theme::PROGRESS_FAIL );
@@ -385,42 +401,38 @@ void K3b::JobProgressDialog::slotFinished( bool success )
 
         if( m_bCanceled ) {
             m_labelTask->setText( i18n("Canceled.") );
-            if( m_osd )
-                m_osd->setText( i18n("Canceled.") );
         }
         else {
             m_labelTask->setText( i18n("Error.") );
-            if( m_osd )
-                m_osd->setText( i18n("Error.") );
         }
-        KNotification::event("FinishedWithError", i18n("Finished with errors"), QPixmap(), 0);
+        KNotification::event("FinishedWithError", i18n("Finished with errors"));
     }
 
     m_labelTask->setPalette( taskPalette );
 
-    showButton( Cancel, false );
-    showButton( User1, true );
-    showButton( User2, true );
+    m_cancelButton->hide();
+    m_showDbgOutButton->show();
+    m_closeButton->show();
 }
 
 
 void K3b::JobProgressDialog::slotCanceled()
 {
-    kDebug();
+    qDebug();
     m_bCanceled = true;
 }
 
 
 void K3b::JobProgressDialog::setJob( K3b::Job* job )
 {
-    kDebug();
+    qDebug();
     m_bCanceled = false;
 
     // clear everything
-    showButton( Cancel, true );
-    showButton( User1, false );
-    showButton( User2, false );
-    enableButtonCancel( true );
+    m_cancelButton->show();
+    m_showDbgOutButton->hide();
+    m_closeButton->hide();
+    m_closeButton->setEnabled( true );
 
     d->viewInfo->clear();
     m_progressPercent->setValue(0);
@@ -429,7 +441,8 @@ void K3b::JobProgressDialog::setJob( K3b::Job* job )
     m_labelSubTask->setText("");
     m_labelProcessedSize->setText("");
     m_labelSubProcessedSize->setText("");
-    m_labelTask->setPalette( k3bappcore->themeManager()->currentTheme()->palette() );
+    if (k3bappcore)
+        m_labelTask->setPalette( k3bappcore->themeManager()->currentTheme()->palette() );
     m_logCache.clear();
 
     // disconnect from the former job
@@ -438,77 +451,53 @@ void K3b::JobProgressDialog::setJob( K3b::Job* job )
     m_job = job;
 
     if( job ) {
-        kDebug() << "connecting";
-        connect( job, SIGNAL(infoMessage(const QString&,int)), this, SLOT(slotInfoMessage(const QString&,int)) );
+        qDebug() << "connecting";
+        connect( job, SIGNAL(infoMessage(QString,int)), this, SLOT(slotInfoMessage(QString,int)) );
 
         connect( job, SIGNAL(percent(int)), m_progressPercent, SLOT(setValue(int)) );
         connect( job, SIGNAL(percent(int)), this, SLOT(slotProgress(int)) );
         connect( job, SIGNAL(subPercent(int)), m_progressSubPercent, SLOT(setValue(int)) );
 
-        connect( job, SIGNAL(processedSubSize(int, int)), this, SLOT(slotProcessedSubSize(int, int)) );
-        connect( job, SIGNAL(processedSize(int, int)), this, SLOT(slotProcessedSize(int, int)) );
+        connect( job, SIGNAL(processedSubSize(int,int)), this, SLOT(slotProcessedSubSize(int,int)) );
+        connect( job, SIGNAL(processedSize(int,int)), this, SLOT(slotProcessedSize(int,int)) );
 
-        connect( job, SIGNAL(newTask(const QString&)), this, SLOT(slotNewTask(const QString&)) );
-        connect( job, SIGNAL(newSubTask(const QString&)), this, SLOT(slotNewSubTask(const QString&)) );
+        connect( job, SIGNAL(newTask(QString)), this, SLOT(slotNewTask(QString)) );
+        connect( job, SIGNAL(newSubTask(QString)), this, SLOT(slotNewSubTask(QString)) );
         connect( job, SIGNAL(started()), this, SLOT(slotStarted()) );
         connect( job, SIGNAL(finished(bool)), this, SLOT(slotFinished(bool)) );
         connect( job, SIGNAL(canceled()), this, SLOT(slotCanceled()) );
 
-        connect( job, SIGNAL(debuggingOutput(const QString&, const QString&)),
-                 this, SLOT(slotDebuggingOutput(const QString&, const QString&)) );
+        connect( job, SIGNAL(debuggingOutput(QString,QString)),
+                 this, SLOT(slotDebuggingOutput(QString,QString)) );
 
         m_labelJob->setText( m_job->jobDescription() );
         m_labelJobDetails->setText( m_job->jobDetails() );
 
-        setCaption( m_job->jobDescription() );
+        setWindowTitle( m_job->jobDescription() );
 
-        if( KConfigGroup( KGlobal::config(), "General Options" ).readEntry( "Show progress OSD", true ) ) {
-            if( !m_osd )
-                m_osd = new K3b::JobProgressOSD( this );
-        }
-        else
-            delete m_osd;
-
-        if( m_osd ) {
-            m_osd->setText( job->jobDescription() );
-            // FIXME: use a setJob method and let the osd also change the text color to red/green
-            //      connect( job, SIGNAL(newTask(const QString&)), m_osd, SLOT(setText(const QString&)) );
-            connect( job, SIGNAL(percent(int)), m_osd, SLOT(setProgress(int)) );
+        if( KConfigGroup( KSharedConfig::openConfig(), "General Options" ).readEntry( "Show progress OSD", true ) ) {
+            KIO::getJobTracker()->registerJob( new KJobBridge( *job ) );
         }
     }
 }
 
 
-void K3b::JobProgressDialog::slotButtonClicked( int button )
+void K3b::JobProgressDialog::reject()
 {
-    kDebug() << button;
-
-    switch( button ) {
-    case KDialog::Cancel:
-        if( m_job && m_job->active() ) {
-            if( KMessageBox::questionYesNo( this, i18n("Do you really want to cancel?"), i18n("Cancel Confirmation") ) == KMessageBox::Yes ) {
-                if( m_job ) {
-                    m_job->cancel();
-                    enableButtonCancel( false );  // do not cancel twice
-                }
+    if( m_job && m_job->active() ) {
+        if( KMessageBox::questionYesNo( this, i18n("Do you really want to cancel?"), i18n("Cancel Confirmation") ) == KMessageBox::Yes ) {
+            if( m_job ) {
+                m_job->cancel();
+                m_closeButton->setEnabled(true);
             }
         }
-        break;
-
-    case KDialog::User1:
-        slotShowDebuggingOutput();
-        break;
-
-    case KDialog::User2:
-        close();
-        break;
     }
 }
 
 
 void K3b::JobProgressDialog::slotNewSubTask(const QString& name)
 {
-    kDebug() << name;
+    qDebug() << name;
     m_labelSubTask->setText(name);
     m_labelSubProcessedSize->setText("");
     m_progressSubPercent->setValue(0);
@@ -517,15 +506,16 @@ void K3b::JobProgressDialog::slotNewSubTask(const QString& name)
 
 void K3b::JobProgressDialog::slotNewTask(const QString& name)
 {
-    kDebug() << name;
+    qDebug() << name;
     m_labelTask->setText( name );
 }
 
 
 void K3b::JobProgressDialog::slotStarted()
 {
-    kDebug();
+    qDebug();
     d->lastProgress = 0;
+    m_lastProgressUpdateTime = 0;
     m_timer.start();
     m_plainCaption = k3bappcore->k3bMainWindow()->windowTitle();
 
@@ -554,18 +544,18 @@ void K3b::JobProgressDialog::slotProgress( int percent )
         d->lastProgress = percent;
         k3bappcore->k3bMainWindow()->setPlainCaption( QString( "(%1%) %2" ).arg(percent).arg(m_plainCaption) );
 
-        setCaption( QString( "(%1%) %2" ).arg(percent).arg(m_job->jobDescription()) );
+        setWindowTitle( QString( "(%1%) %2" ).arg(percent).arg(m_job->jobDescription()) );
     }
 
     if( m_timer.isValid() ) {
 	qint64 elapsed = m_timer.elapsed();
-        m_labelElapsedTime->setText( i18nc( "@info %1 is a duration formatted using KLocale::prettyFormatDuration",
-            "Elapsed time: %1", KGlobal::locale()->prettyFormatDuration( elapsed ) ) );
+        m_labelElapsedTime->setText( i18nc( "@info %1 is a duration formatted using QLocale::toString",
+            "Elapsed time: %1", QLocale().toString( QTime().addSecs( elapsed ), QLocale::NarrowFormat ) ) );
         // Update "Remaining time" max. each second (1000 ms)
         if ( elapsed - m_lastProgressUpdateTime > 999 ) {
-            m_labelRemainingTime->setText( i18nc( "@info %1 is a duration formatted using KLocale::prettyFormatDuration",
-                "Remaining: %1", KGlobal::locale()->prettyFormatDuration(
-                ( d->lastProgress > 0 && d->lastProgress < 100 ) ? elapsed * ( 100 - d->lastProgress) / d->lastProgress : 0 ) ) );
+            m_labelRemainingTime->setText( i18nc( "@info %1 is a duration formatted using QLocale::toString",
+                "Remaining: %1", QLocale().toString( QTime().addSecs(
+                ( d->lastProgress > 0 && d->lastProgress < 100 ) ? elapsed * ( 100 - d->lastProgress) / d->lastProgress : 0 ), QLocale::NarrowFormat ) ) );
             m_lastProgressUpdateTime = elapsed;
         }
     }
@@ -574,26 +564,26 @@ void K3b::JobProgressDialog::slotProgress( int percent )
 
 void K3b::JobProgressDialog::keyPressEvent( QKeyEvent* e )
 {
-    kDebug() << e;
+    qDebug() << e;
 
     switch ( e->key() ) {
     case Qt::Key_Enter:
     case Qt::Key_Return:
         // if the process finished this closes the dialog
-        if( button( User2 )->isVisible() )
-            close();
+        if( m_closeButton->isVisible() )
+            accept();
         break;
 
     case Qt::Key_Escape:
         // simulate button clicks
         if( m_job && m_job->active() )
-            slotButtonClicked( KDialog::Cancel );
-        else if( button( User2 )->isVisible() )
-            close();
+            reject();
+        else if( m_closeButton->isVisible() )
+            accept();
         break;
 
     default:
-        KDialog::keyPressEvent( e );
+        QDialog::keyPressEvent( e );
         break;
     }
 }
@@ -601,7 +591,7 @@ void K3b::JobProgressDialog::keyPressEvent( QKeyEvent* e )
 
 QSize K3b::JobProgressDialog::sizeHint() const
 {
-    QSize s = KDialog::sizeHint();
+    QSize s = QDialog::sizeHint();
     if( s.width() < s.height() )
         s.setWidth( s.height() );
     return s;
@@ -612,11 +602,10 @@ int K3b::JobProgressDialog::startJob( K3b::Job* job )
 {
     if( job ) {
         setJob( job );
-        //FIXME kde4
-        //k3bappcore->jobInterface()->setJob( job );
+        new JobInterface( job );
     }
     else if( !m_job ) {
-        kError() << "(K3b::JobProgressDialog) null job!" << endl;
+        qCritical() << "(K3b::JobProgressDialog) null job!" << endl;
         return -1;
     }
 
@@ -657,10 +646,12 @@ void K3b::JobProgressDialog::blockingInformation( const QString& text,
 
 void K3b::JobProgressDialog::slotThemeChanged()
 {
+    if (k3bappcore == Q_NULLPTR)
+        return;
     if( K3b::Theme* theme = k3bappcore->themeManager()->currentTheme() ) {
         d->progressHeaderFrame->setPalette( theme->palette() );
         d->headerFrame->setPalette( theme->palette() );
     }
 }
 
-#include "k3bjobprogressdialog.moc"
+
