@@ -1,6 +1,7 @@
 /*
  *
  * Copyright (C) 2003-2008 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 2011 Michal Malek <michalm@jabster.pl>
  *
  * This file is part of the K3b project.
  * Copyright (C) 1998-2008 Sebastian Trueg <trueg@k3b.org>
@@ -16,9 +17,9 @@
 #include <config-k3b.h>
 
 
-#include "k3bapplication.h"
 #include "k3bsystemproblemdialog.h"
-#include "k3bpassivepopup.h"
+#include "k3b.h"
+#include "k3bapplication.h"
 #include "k3bthemedheader.h"
 #include "k3btitlelabel.h"
 #include "k3bexternalbinmanager.h"
@@ -32,24 +33,27 @@
 #include "k3bthememanager.h"
 #include "k3bcore.h"
 
-#include <KColorScheme>
-#include <KConfigGroup>
-#include <KGlobal>
-#include <KLocale>
-#include <KMessageBox>
-#include <KProcess>
-#include <KPushButton>
-#include <KStandardGuiItem>
-#include <KTextEdit>
+#include <KConfigWidgets/KColorScheme>
+#include <KConfigCore/KConfigGroup>
+#include <KConfigCore/KSharedConfig>
+#include <KCoreAddons/KProcess>
+#include <KNotifications/KNotification>
+#include <KI18n/KLocalizedString>
+#include <KWidgetsAddons/KMessageBox>
+#include <KWidgetsAddons/KStandardGuiItem>
 
-#include <QCheckBox>
-#include <QCloseEvent>
-#include <QFileInfo>
-#include <QGridLayout>
-#include <QHBoxLayout>
-#include <QList>
+#include <QtCore/QFileInfo>
+#include <QtCore/QList>
+#include <QtGui/QCloseEvent>
+#include <QtGui/QIcon>
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QDialogButtonBox>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QTextEdit>
 
-#ifdef HAVE_ICONV_H
+#ifdef HAVE_ICONV
 #include <langinfo.h>
 #endif
 
@@ -81,54 +85,49 @@ K3b::SystemProblem::SystemProblem( Type t,
 
 
 K3b::SystemProblemDialog::SystemProblemDialog( const QList<K3b::SystemProblem>& problems,
-                                               bool showK3bSetupButton,
+                                               bool showDeviceSettingsButton,
+                                               bool showBinSettingsButton,
                                                QWidget* parent)
-    : KDialog( parent )
+    : QDialog( parent )
 {
-    setCaption( i18n("System Configuration Problems") );
-    setButtons(KDialog::None);
-    QWidget *widget = new QWidget(this);
-    setMainWidget(widget);
+    setWindowTitle( i18n("System Configuration Problems") );
     // setup the title
     // ---------------------------------------------------------------------------------------------------
-    K3b::ThemedHeader* titleFrame = new K3b::ThemedHeader( widget );
+    K3b::ThemedHeader* titleFrame = new K3b::ThemedHeader( this );
     titleFrame->setTitle( i18n("System Configuration Problems"),
                           i18np("1 problem", "%1 problems", problems.count() ) );
 
-    KPushButton* closeButton = new KPushButton( KStandardGuiItem::close(), widget );
-    connect( closeButton, SIGNAL(clicked()), this, SLOT(close()) );
-    m_checkDontShowAgain = new QCheckBox( i18n("Do not show again"), widget );
+    QDialogButtonBox* buttonBox = new QDialogButtonBox( this );
+    connect( buttonBox, SIGNAL(accepted()), SLOT(accept()) );
+    connect( buttonBox, SIGNAL(rejected()), SLOT(reject()) );
 
-    QPushButton* k3bsetupButton = 0;
-#ifdef BUILD_K3BSETUP
-    if( showK3bSetupButton ) {
-        k3bsetupButton = new QPushButton( i18n("Modify Permissions..."), widget );
-        connect( k3bsetupButton, SIGNAL(clicked()), this, SLOT(slotK3bSetup()) );
+    if( showDeviceSettingsButton || showBinSettingsButton ) {
+        QPushButton* configureButton = buttonBox->addButton( i18n("Configure K3b..."), QDialogButtonBox::NoRole );
+        if( showDeviceSettingsButton ) {
+            connect( configureButton, SIGNAL(clicked()), SLOT(slotShowDeviceSettings()) );
+        } else if( showBinSettingsButton ) {
+            connect( configureButton, SIGNAL(clicked()), SLOT(slotShowBinSettings()) );
+       }
     }
-#else
-    Q_UNUSED( showK3bSetupButton );
-#endif
+
+    buttonBox->addButton( QDialogButtonBox::Close );
+
+    m_checkDontShowAgain = new QCheckBox( i18n("Do not show again"), this );
 
     // setup the problem view
     // ---------------------------------------------------------------------------------------------------
-    KTextEdit* view = new KTextEdit( widget );
+    QTextEdit* view = new QTextEdit( this );
     view->setReadOnly(true);
 
     // layout everything
-    QGridLayout* grid = new QGridLayout( widget );
+    QGridLayout* grid = new QGridLayout( this );
     grid->addWidget( titleFrame, 0, 0, 1, 2 );
     grid->addWidget( view, 1, 0, 1, 2 );
     grid->addWidget( m_checkDontShowAgain, 2, 0 );
-    QHBoxLayout* buttonBox = new QHBoxLayout;
-    buttonBox->setMargin( 0 );
-    if( k3bsetupButton != 0 ) {
-        buttonBox->addWidget( k3bsetupButton );
-    }
-    buttonBox->addWidget( closeButton );
-    grid->addLayout( buttonBox, 2, 1 );
+    grid->addWidget( buttonBox, 2, 1 );
     grid->setColumnStretch( 0, 1 );
     grid->setRowStretch( 1, 1 );
-    
+
     const KColorScheme colorScheme( QPalette::Normal, KColorScheme::Button );
     const QColor negativeTextColor = colorScheme.foreground( KColorScheme::NegativeText ).color();
 
@@ -163,7 +162,7 @@ K3b::SystemProblemDialog::SystemProblemDialog( const QList<K3b::SystemProblem>&
 void K3b::SystemProblemDialog::closeEvent( QCloseEvent* e )
 {
     if( m_checkDontShowAgain->isChecked() ) {
-        KConfigGroup grp( KGlobal::config(), "General Options" );
+        KConfigGroup grp( KSharedConfig::openConfig(), "General Options" );
         grp.writeEntry( "check system config", false );
     }
 
@@ -174,13 +173,8 @@ void K3b::SystemProblemDialog::closeEvent( QCloseEvent* e )
 void K3b::SystemProblemDialog::checkSystem( QWidget* parent, NotificationLevel level )
 {
     QList<K3b::SystemProblem> problems;
-    bool showK3bSetupButton = false;
-    
-#ifdef BUILD_K3BSETUP
-    const QString k3bSetupSolutionText = i18n("Click \"Modify Permissions...\" to solve this problem.");
-#else
-    const QString k3bSetupSolutionText = QString();
-#endif
+    bool showDeviceSettingsButton = false;
+    bool showBinSettingsButton = false;
 
     if( k3bcore->deviceManager()->allDevices().isEmpty() ) {
         problems.append( K3b::SystemProblem( K3b::SystemProblem::CRITICAL,
@@ -199,12 +193,19 @@ void K3b::SystemProblemDialog::checkSystem( QWidget* parent, NotificationLevel l
                                            i18n("K3b did not find an optical writing device in your system. Thus, "
                                                 "you will not be able to burn CDs or DVDs. However, you can still "
                                                 "use other K3b features such as audio track extraction, audio "
-                                                "transcoding or ISO9660 image creation."),
+                                                "transcoding or ISO 9660 image creation."),
                                            QString() ) );
     }
     else {
         // 1. cdrecord, cdrdao
-        if( !k3bcore->externalBinManager()->foundBin( "cdrecord" ) ) {
+        if( !k3bcore->externalBinManager()->binNeedGroup( "cdrecord" ).isEmpty() ) {
+            problems.append( K3b::SystemProblem( K3b::SystemProblem::CRITICAL,
+                                               i18n("Insufficient permissions for %1 executable: %2",QString("cdrecord"),k3bcore->externalBinManager()->binPath("cdrecord")),
+                                               i18n("K3b uses cdrecord to actually write CDs."),
+                                               i18n("Check permissions via Settings -> Configure K3b... -> Programs -> Permissions. "
+                                                    "If K3b's default value is set make sure you are member of \"%1\" group.", k3bcore->externalBinManager()->binNeedGroup( "cdrecord" )) ) );
+        }
+        else if( !k3bcore->externalBinManager()->foundBin( "cdrecord" ) ) {
             problems.append( K3b::SystemProblem( K3b::SystemProblem::CRITICAL,
                                                i18n("Unable to find %1 executable",QString("cdrecord")),
                                                i18n("K3b uses cdrecord to actually write CDs."),
@@ -214,7 +215,7 @@ void K3b::SystemProblemDialog::checkSystem( QWidget* parent, NotificationLevel l
         else {
             if( k3bcore->externalBinManager()->binObject( "cdrecord" )->hasFeature( "outdated" ) ) {
                 problems.append( K3b::SystemProblem( K3b::SystemProblem::NON_CRITICAL,
-                                                   i18n("Used %1 version %2 is outdated",QString("cdrecord"),QString(k3bcore->externalBinManager()->binObject( "cdrecord" )->version)),
+                                                   i18n("Used %1 version %2 is outdated",QString("cdrecord"),QString(k3bcore->externalBinManager()->binObject( "cdrecord" )->version())),
                                                    i18n("Although K3b supports all cdrtools versions since "
                                                         "1.10 it is highly recommended to at least use "
                                                         "version 2.0."),
@@ -230,21 +231,20 @@ void K3b::SystemProblemDialog::checkSystem( QWidget* parent, NotificationLevel l
             // Kernel 2.6.16.something seems to introduce another problem which was apparently worked around in cdrecord 2.01.01a05
             //
             if( K3b::simpleKernelVersion() >= K3b::Version( 2, 6, 8 ) &&
-                k3bcore->externalBinManager()->binObject( "cdrecord" )->version < K3b::Version( 2, 1, 1, "a05" ) &&
-                !k3bcore->externalBinManager()->binObject( "cdrecord" )->hasFeature( "wodim" ) ) {
+                k3bcore->externalBinManager()->binObject( "cdrecord" )->version() < K3b::Version( 2, 1, 1, "a05" ) && !k3bcore->externalBinManager()->binObject( "cdrecord" )->hasFeature( "wodim" ) ) {
                 if( k3bcore->externalBinManager()->binObject( "cdrecord" )->hasFeature( "suidroot" ) ) {
-                    showK3bSetupButton = true;
+                    showBinSettingsButton = true;
                     problems.append( K3b::SystemProblem( K3b::SystemProblem::CRITICAL,
                                                          i18n("%1 will be run with root privileges on kernel >= 2.6.8",QString("cdrecord <= 2.01.01a05")),
                                                          i18n("Since Linux kernel 2.6.8 %1 will not work when run suid "
                                                               "root for security reasons anymore.",
                                                          QLatin1String( "cdrecord <= 2.01.01a05") ),
-                                                         k3bSetupSolutionText ) );
+                                                         i18n("Click \"Configure K3b...\" to solve this problem.") ) );
                 }
             }
 #ifdef CDRECORD_SUID_ROOT_CHECK
             else if( !k3bcore->externalBinManager()->binObject( "cdrecord" )->hasFeature( "suidroot" ) && getuid() != 0 ) { // not root
-                showK3bSetupButton = true;
+                showBinSettingsButton = true;
                 problems.append( K3b::SystemProblem( K3b::SystemProblem::CRITICAL,
                                                      i18n("%1 will be run without root privileges",QString("cdrecord")),
                                                      i18n("It is highly recommended to configure cdrecord "
@@ -253,13 +253,21 @@ void K3b::SystemProblemDialog::checkSystem( QWidget* parent, NotificationLevel l
                                                           "stability of the burning process. As well as this, "
                                                           "it allows the size of the burning buffer to be changed, "
                                                           "and a lot of user problems can be solved this way."),
-                                                     k3bSetupSolutionText ) );
+                                                     i18n("Click \"Configure K3b...\" to solve this problem.") ) );
             }
 #endif // CDRECORD_SUID_ROOT_CHECK
 #endif
         }
 
-        if( !k3bcore->externalBinManager()->foundBin( "cdrdao" ) ) {
+        if( !k3bcore->externalBinManager()->binNeedGroup( "cdrdao" ).isEmpty() ) {
+            problems.append( K3b::SystemProblem( K3b::SystemProblem::CRITICAL,
+                                               i18n("Insufficient permissions for %1 executable: %2",QString("cdrdao"),k3bcore->externalBinManager()->binPath("cdrdao")),
+                                               i18n("K3b uses cdrdao to actually write CDs."),
+                                               i18n("Check permissions via Settings -> Configure K3b... -> Programs -> Permissions. "
+                                                    "If K3b's default value is set make sure you are member of \"%1\" group.", k3bcore->externalBinManager()->binNeedGroup( "cdrdao" )) ) ) ;
+        }
+
+        else if( !k3bcore->externalBinManager()->foundBin( "cdrdao" ) ) {
             problems.append( K3b::SystemProblem( K3b::SystemProblem::CRITICAL,
                                                i18n("Unable to find %1 executable",QString("cdrdao")),
                                                i18n("K3b uses cdrdao to actually write CDs."),
@@ -269,22 +277,40 @@ void K3b::SystemProblemDialog::checkSystem( QWidget* parent, NotificationLevel l
 #ifdef Q_OS_LINUX
 #ifdef CDRECORD_SUID_ROOT_CHECK
             if( !k3bcore->externalBinManager()->binObject( "cdrdao" )->hasFeature( "suidroot" ) && getuid() != 0 ) {
-                showK3bSetupButton = true;
+                showBinSettingsButton = true;
                 problems.append( K3b::SystemProblem( K3b::SystemProblem::CRITICAL,
                                                      i18n("%1 will be run without root privileges",QString("cdrdao")),
                                                      i18n("It is highly recommended to configure cdrdao "
                                                           "to run with root privileges to increase the "
                                                           "overall stability of the burning process."),
-                                                     k3bSetupSolutionText ) );
+                                                     i18n("Click \"Configure K3b...\" to solve this problem.") ) );
             }
 #endif // CDRECORD_SUID_ROOT_CHECK
 #endif
         }
+
+        if (!k3bcore->externalBinManager()->foundBin("cdrskin")) {
+            problems.append(K3b::SystemProblem(K3b::SystemProblem::CRITICAL,
+                i18n("Unable to find %1 executable", QString("cdrskin")),
+                i18n("K3b uses cdrskin in place of cdrecord."),
+                i18n("Install the libburn package which contains cdrskin")));
+        }
     }
 
 
     if( !k3bcore->deviceManager()->dvdWriter().isEmpty() ) {
-        if( !k3bcore->externalBinManager()->foundBin( "growisofs" ) ) {
+
+        if( !k3bcore->externalBinManager()->binNeedGroup( "growisofs" ).isEmpty() ) {
+            problems.append( K3b::SystemProblem( K3b::SystemProblem::CRITICAL,
+                                               i18n("Insufficient permissions for %1 executable: %2",QString("growisofs"),k3bcore->externalBinManager()->binPath("growisofs")),
+                                               i18n("K3b uses growisofs to actually write DVDs. "
+                                                    "Without growisofs you will not be able to write DVDs. "
+                                                    "Make sure to install at least version 5.10."),
+                                               i18n("Check permissions via Settings -> Configure K3b... -> Programs -> Permissions. "
+                                                    "If K3b's default value is set make sure you are member of \"%1\" group.", k3bcore->externalBinManager()->binNeedGroup( "growisofs" )) ) );
+        }
+
+        else if( !k3bcore->externalBinManager()->foundBin( "growisofs" ) ) {
             problems.append( K3b::SystemProblem( K3b::SystemProblem::CRITICAL,
                                                i18n("Unable to find %1 executable",QString("growisofs")),
                                                i18n("K3b uses growisofs to actually write DVDs. "
@@ -293,24 +319,24 @@ void K3b::SystemProblemDialog::checkSystem( QWidget* parent, NotificationLevel l
                                                i18n("Install the dvd+rw-tools package.") ) );
         }
         else {
-            if( k3bcore->externalBinManager()->binObject( "growisofs" )->version < K3b::Version( 5, 10 ) ) {
+            if( k3bcore->externalBinManager()->binObject( "growisofs" )->version() < K3b::Version( 5, 10 ) ) {
                 problems.append( K3b::SystemProblem( K3b::SystemProblem::CRITICAL,
-                                                   i18n("Used %1 version %2 is outdated",QString("growisofs"),k3bcore->externalBinManager()->binObject( "growisofs" )->version),
+                                                   i18n("Used %1 version %2 is outdated",QString("growisofs"),k3bcore->externalBinManager()->binObject( "growisofs" )->version()),
                                                    i18n("K3b needs at least growisofs version 5.10 to write DVDs. "
                                                         "All older versions will not work and K3b will refuse to use them."),
                                                    i18n("Install a more recent version of %1.",QString("growisofs")) ) );
             }
-            else if( k3bcore->externalBinManager()->binObject( "growisofs" )->version < K3b::Version( 5, 12 ) ) {
+            else if( k3bcore->externalBinManager()->binObject( "growisofs" )->version() < K3b::Version( 5, 12 ) ) {
                 problems.append( K3b::SystemProblem( K3b::SystemProblem::NON_CRITICAL,
-                                                   i18n("Used %1 version %2 is outdated",QString("growisofs"),k3bcore->externalBinManager()->binObject( "growisofs" )->version),
+                                                   i18n("Used %1 version %2 is outdated",QString("growisofs"),k3bcore->externalBinManager()->binObject( "growisofs" )->version()),
                                                    i18n("K3b will not be able to copy DVDs on-the-fly or write a DVD+RW in multiple "
                                                         "sessions using a growisofs "
                                                         "version older than 5.12."),
                                                    i18n("Install a more recent version of %1.",QString("growisofs")) ) );
             }
-            else if( k3bcore->externalBinManager()->binObject( "growisofs" )->version < K3b::Version( 7, 0 ) ) {
+            else if( k3bcore->externalBinManager()->binObject( "growisofs" )->version() < K3b::Version( 7, 0 ) ) {
                 problems.append( K3b::SystemProblem( K3b::SystemProblem::NON_CRITICAL,
-                                                   i18n("Used %1 version %2 is outdated",QString("growisofs"),k3bcore->externalBinManager()->binObject( "growisofs" )->version),
+                                                   i18n("Used %1 version %2 is outdated",QString("growisofs"),k3bcore->externalBinManager()->binObject( "growisofs" )->version()),
                                                    i18n("It is highly recommended to use growisofs 7.0 or higher. "
                                                         "K3b will not be able to write a DVD+RW in multiple "
                                                         "sessions using a growisofs version older than 7.0." ),
@@ -318,14 +344,14 @@ void K3b::SystemProblemDialog::checkSystem( QWidget* parent, NotificationLevel l
             }
 //            // for now we ignore the suid root bit becasue of the memorylocked issue
 //            else if( !k3bcore->externalBinManager()->binObject( "growisofs" )->hasFeature( "suidroot" ) ) {
-//                showK3bSetupButton = true;
+//                showBinSettingsButton = true;
 //                problems.append( K3b::SystemProblem( K3b::SystemProblem::CRITICAL,
 //                                                     i18n("%1 will be run without root privileges","growisofs"),
 //                                                     i18n("It is highly recommended to configure growisofs "
 //                                                          "to run with root privileges. Only then growisofs "
 //                                                          "runs with high priority which increases the overall "
 //                                                          "stability of the burning process."),
-//                                                     k3bSetupSolutionText ) );
+//                                                     i18n("Click \"Configure K3b...\" to solve this problem.") ) );
 //            }
         }
 
@@ -344,7 +370,7 @@ void K3b::SystemProblemDialog::checkSystem( QWidget* parent, NotificationLevel l
         problems.append( K3b::SystemProblem( K3b::SystemProblem::CRITICAL,
                                            i18n("Used %1 version %2 is outdated",
                                                 QString("mkisofs"),
-                                                k3bcore->externalBinManager()->binObject( "mkisofs" )->version),
+                                                k3bcore->externalBinManager()->binObject( "mkisofs" )->version()),
                                            i18n("K3b needs at least mkisofs version 1.14. Older versions may introduce problems "
                                                 "when creating data projects."),
                                            i18n("Install a more recent version of %1.",QString("mkisofs")) ) );
@@ -405,15 +431,15 @@ void K3b::SystemProblemDialog::checkSystem( QWidget* parent, NotificationLevel l
                     !( k3bcore->externalBinManager()->binObject( "cdrecord" )->hasFeature( "plain-atapi" ) &&
                        K3b::plainAtapiSupport() ) ) {
                     problems.append( K3b::SystemProblem( K3b::SystemProblem::CRITICAL,
-                                                       i18n("%1 %2 does not support ATAPI",QString("cdrecord"),k3bcore->externalBinManager()->binObject("cdrecord")->version),
+                                                       i18n("%1 %2 does not support ATAPI",QString("cdrecord"),k3bcore->externalBinManager()->binObject("cdrecord")->version()),
                                                        i18n("The configured version of %1 does not "
                                                             "support writing to ATAPI devices without "
                                                             "SCSI emulation and there is at least one writer "
                                                             "in your system not configured to use "
                                                             "SCSI emulation.",QString("cdrecord")),
-                                                       i18n("The best and recommended solution is to enable "
-                                                            "ide-scsi (SCSI emulation) for all devices. "
-                                                            "This way you will not have any problems. Or you install "
+                                                       i18n("The best, and recommended, solution is to use "
+                                                            "ide-scsi (SCSI emulation) for all writer devices: "
+                                                            "this way you will not have any problems; or, you can install "
                                                             "(or select as the default) a more recent version of %1.",QString("cdrtools")) ) );
                 }
             }
@@ -426,7 +452,7 @@ void K3b::SystemProblemDialog::checkSystem( QWidget* parent, NotificationLevel l
                     problems.append( K3b::SystemProblem( K3b::SystemProblem::CRITICAL,
                                                        i18n("%1 %2 does not support ATAPI",
                                                             QLatin1String( "cdrdao"),
-                                                            k3bcore->externalBinManager()->binObject("cdrdao")->version.toString() ),
+                                                            k3bcore->externalBinManager()->binObject("cdrdao")->version().toString() ),
                                                        i18n("The configured version of %1 does not "
                                                             "support writing to ATAPI devices without "
                                                             "SCSI emulation and there is at least one writer "
@@ -445,10 +471,10 @@ void K3b::SystemProblemDialog::checkSystem( QWidget* parent, NotificationLevel l
         }
     }
 
-    if( dvd_r_dl && k3bcore->externalBinManager()->foundBin( "growisofs" ) ) {
-        if( k3bcore->externalBinManager()->binObject( "growisofs" )->version < K3b::Version( 6, 0 ) ) {
+    if( dvd_r_dl && k3bcore->externalBinManager()->foundBin( "growisofs" ) && k3bcore->externalBinManager()->binNeedGroup( "growisofs" ).isEmpty() ) {
+        if( k3bcore->externalBinManager()->binObject( "growisofs" )->version() < K3b::Version( 6, 0 ) ) {
             problems.append( K3b::SystemProblem( K3b::SystemProblem::NON_CRITICAL,
-                                               i18n("Used %1 version %2 is outdated",QString("growisofs"),k3bcore->externalBinManager()->binObject( "growisofs" )->version),
+                                               i18n("Used %1 version %2 is outdated",QString("growisofs"),k3bcore->externalBinManager()->binObject( "growisofs" )->version()),
                                                i18n("K3b will not be able to write DVD-R Dual Layer media using a growisofs "
                                                     "version older than 6.0."),
                                                i18n("Install a more recent version of growisofs.") ) );
@@ -461,7 +487,7 @@ void K3b::SystemProblemDialog::checkSystem( QWidget* parent, NotificationLevel l
         K3b::Device::Device* dev = (*it);
 #ifndef Q_OS_WIN32
         if( !QFileInfo( dev->blockDeviceName() ).isWritable() ) {
-            showK3bSetupButton = true;
+            showDeviceSettingsButton = true;
             problems.append( K3b::SystemProblem( K3b::SystemProblem::CRITICAL,
                                                i18n("No write access to device %1",dev->blockDeviceName()),
                                                i18n("K3b needs write access to all the devices to perform certain tasks. "
@@ -509,7 +535,7 @@ void K3b::SystemProblemDialog::checkSystem( QWidget* parent, NotificationLevel l
     bool haveMp3Decoder = false;
     for( QList<K3b::Plugin*>::const_iterator it = plugins.constBegin();
          it != plugins.constEnd(); ++it ) {
-        if( (*it)->pluginInfo().pluginName() == "k3bmaddecoder" ) {
+        if( (*it)->pluginInfo().isValid() && (*it)->pluginInfo().pluginName() == "k3bmaddecoder" ) {
             haveMp3Decoder = true;
             break;
         }
@@ -526,7 +552,7 @@ void K3b::SystemProblemDialog::checkSystem( QWidget* parent, NotificationLevel l
                                                 "via an online update tool.") ) );
     }
 
-#ifdef HAVE_ICONV_H
+#ifdef HAVE_ICONV
     char* codec = nl_langinfo( CODESET );
     if( strcmp( codec, "ANSI_X3.4-1968" ) == 0 ) {
         //
@@ -551,68 +577,71 @@ void K3b::SystemProblemDialog::checkSystem( QWidget* parent, NotificationLevel l
     // the kdelibs refuse it.
     //
     if( ::getuid() == 0 ) {
-        showK3bSetupButton = true;
+        showDeviceSettingsButton = true;
         problems.append( K3b::SystemProblem( K3b::SystemProblem::WARNING,
                                            i18n("Running K3b as root user"),
                                            i18n("It is not recommended to run K3b under the root user account. "
                                                 "This introduces unnecessary security risks."),
                                            i18n("Run K3b from a proper user account and setup the device and "
                                                 "external tool permissions appropriately.")
-#ifdef BUILD_K3BSETUP
-                                           + ' ' + i18n("The latter can be done via \"Modify Permissions...\".")
-#endif
+                                           + ' ' + i18n("The latter can be done via \"Configure K3b...\".")
                                            ) );
     }
 
 
-    kDebug() << "(K3b::Core) System problems:";
+    qDebug() << "(K3b::Core) System problems:";
     for( QList<K3b::SystemProblem>::const_iterator it = problems.constBegin();
          it != problems.constEnd(); ++it ) {
         const K3b::SystemProblem& p = *it;
 
         switch( p.type ) {
         case K3b::SystemProblem::CRITICAL:
-            kDebug() << " CRITICAL";
+            qDebug() << " CRITICAL";
             break;
         case K3b::SystemProblem::NON_CRITICAL:
-            kDebug() << " NON_CRITICAL";
+            qDebug() << " NON_CRITICAL";
             break;
         case K3b::SystemProblem::WARNING:
-            kDebug() << " WARNING";
+            qDebug() << " WARNING";
             break;
         }
-        kDebug() << " PROBLEM:  " << p.problem << endl
+        qDebug() << " PROBLEM:  " << p.problem << endl
                  << " DETAILS:  " << p.details << endl
                  << " SOLUTION: " << p.solution << endl << endl;
 
     }
     if( problems.isEmpty() ) {
-        kDebug() << "          - none - ";
+        qDebug() << "          - none - ";
         if( level == AlwaysNotify ) {
-            K3b::PassivePopup::showPopup( i18n("No problems found in system configuration."), i18n("System configured properly") );
+            KNotification::event( "NoProblemsFound",
+                                  i18n("System configured properly"),
+                                  i18n("No problems found in system configuration.") );
         }
     }
     else {
         static K3b::SystemProblemDialog* s_openDlg = 0;
         if( s_openDlg )
             s_openDlg->close();
-        K3b::SystemProblemDialog dlg( problems, showK3bSetupButton, parent );
+        K3b::SystemProblemDialog dlg( problems, showDeviceSettingsButton, showBinSettingsButton, parent );
         s_openDlg = &dlg;
         dlg.exec();
         s_openDlg = 0;
     }
 
     // remember which version of K3b checked the system the last time
-    KConfigGroup cfg( KGlobal::config(), "General Options" );
+    KConfigGroup cfg( KSharedConfig::openConfig(), "General Options" );
     cfg.writeEntry( "Last system check version", QString(k3bcore->version()) );
 }
 
-void K3b::SystemProblemDialog::slotK3bSetup()
+void K3b::SystemProblemDialog::slotShowDeviceSettings()
 {
-    QStringList args;
-    args << "k3bsetup" << "--lang" << KGlobal::locale()->language();
-    if( !KProcess::startDetached( K3b::findExe("kcmshell4"), args ) )
-        KMessageBox::error( 0, i18n("Unable to start K3b::Setup.") );
+    k3bappcore->k3bMainWindow()->showOptionDialog( OptionDialog::Devices );
+}
+
+
+void K3b::SystemProblemDialog::slotShowBinSettings()
+{
+    k3bappcore->k3bMainWindow()->showOptionDialog( OptionDialog::Programs );
 }
 
 
@@ -683,7 +712,7 @@ QList<K3b::Device::Device*> K3b::SystemProblemDialog::checkForAutomounting()
 
 bool K3b::SystemProblemDialog::readCheckSystemConfig()
 {
-    KConfigGroup cfgGrp( KGlobal::config(), "General Options" );
+    KConfigGroup cfgGrp( KSharedConfig::openConfig(), "General Options" );
 
     K3b::Version configVersion( cfgGrp.readEntry( "Last system check version", "0.1" ) );
     if( configVersion < k3bcore->version() )
@@ -692,4 +721,4 @@ bool K3b::SystemProblemDialog::readCheckSystemConfig()
     return cfgGrp.readEntry( "check system config", true );
 }
 
-#include "k3bsystemproblemdialog.moc"
+
