@@ -15,10 +15,10 @@
 
 #include "k3bnotifyoptiontab.h"
 
-#include <kdebug.h>
-#include <KNotifyConfigWidget>
+#include <KNotifyConfig/KNotifyConfigWidget>
 
-#include <QtGui/QHBoxLayout>
+#include <QtCore/QDebug>
+#include <QtWidgets/QHBoxLayout>
 
 
 
@@ -28,7 +28,7 @@ K3b::NotifyOptionTab::NotifyOptionTab( QWidget* parent )
     m_notifyWidget = new KNotifyConfigWidget(this);
     m_notifyWidget->setApplication();
     QHBoxLayout* layout = new QHBoxLayout( this );
-    layout->setMargin( 0 );
+    layout->setContentsMargins( 0, 0, 0, 0 );
     layout->addWidget( m_notifyWidget );
 }
 
@@ -49,4 +49,4 @@ bool K3b::NotifyOptionTab::saveSettings()
     return true;
 }
 
-#include "k3bnotifyoptiontab.moc"
+
