@@ -1,7 +1,7 @@
 /*
  *
  * Copyright (C) 2003-2009 Sebastian Trueg <trueg@k3b.org>
- * Copyright (C) 2009-2010 Michal Malek <michalm@jabster.pl>
+ * Copyright (C) 2009-2011 Michal Malek <michalm@jabster.pl>
  *
  * This file is part of the K3b project.
  * Copyright (C) 1998-2009 Sebastian Trueg <trueg@k3b.org>
@@ -25,37 +25,36 @@
 #include "k3bmediacache.h"
 #include "k3baction.h"
 
-#include <QBrush>
-#include <QColor>
-#include <QEvent>
-#include <QFont>
-#include <QFontMetrics>
-#include <QFrame>
-#include <QGridLayout>
-#include <QLinearGradient>
-#include <QMouseEvent>
-#include <QPainter>
-#include <QPaintEvent>
-#include <QPixmap>
-#include <QRect>
-#include <QStyle>
-#include <QTimer>
-#include <QToolButton>
-#include <QToolTip>
-#include <QValidator>
-#include <QWhatsThis>
+#include <KConfigWidgets/KColorScheme>
+#include <KConfigCore/KConfigGroup>
+#include <KConfigCore/KSharedConfig>
+#include <KI18n/KLocalizedString>
+#include <KIOCore/KIO/Global>
+#include <KWidgetsAddons/KMessageBox>
 
-#include <KAction>
-#include <KColorScheme>
-#include <KConfigGroup>
-#include <KDebug>
-#include <KGlobal>
-#include <KInputDialog>
-#include <KLocale>
-#include <KIconLoader>
-#include <kio/global.h>
-#include <KMenu>
-#include <KMessageBox>
+#include <QtCore/QDebug>
+#include <QtCore/QEvent>
+#include <QtCore/QLocale>
+#include <QtCore/QRect>
+#include <QtCore/QTimer>
+#include <QtGui/QBrush>
+#include <QtGui/QColor>
+#include <QtGui/QFont>
+#include <QtGui/QFontMetrics>
+#include <QtGui/QMouseEvent>
+#include <QtGui/QPainter>
+#include <QtGui/QPaintEvent>
+#include <QtGui/QPixmap>
+#include <QtGui/QValidator>
+#include <QtWidgets/QFrame>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QInputDialog>
+#include <QtWidgets/QMenu>
+#include <QtWidgets/QStyle>
+#include <QtWidgets/QStyleOptionProgressBarV2>
+#include <QtWidgets/QToolButton>
+#include <QtWidgets/QToolTip>
+#include <QtWidgets/QWhatsThis>
 
 
 class K3b::FillStatusDisplayWidget::Private
@@ -110,8 +109,8 @@ QSize K3b::FillStatusDisplayWidget::sizeHint() const
 
 QSize K3b::FillStatusDisplayWidget::minimumSizeHint() const
 {
-    int margin = 2;
-    QFontMetrics fm( font() );
+    const int margin = style()->pixelMetric( QStyle::PM_ButtonMargin );
+    const QFontMetrics fm( font() );
     return QSize( -1, fm.height() + 2 * margin );
 }
 
@@ -125,86 +124,49 @@ void K3b::FillStatusDisplayWidget::mousePressEvent( QMouseEvent* e )
 
 void K3b::FillStatusDisplayWidget::paintEvent( QPaintEvent* )
 {
-    const KColorScheme colorScheme( isEnabled() ? QPalette::Normal : QPalette::Disabled, KColorScheme::Window );
-    const QColor positiveBg = colorScheme.background( KColorScheme::PositiveBackground ).color();
-    const QColor neutralBg = colorScheme.background( KColorScheme::NeutralBackground ).color();
-    const QColor negativeBg = colorScheme.background( KColorScheme::NegativeBackground ).color();
-    const QColor normalFg = colorScheme.foreground( KColorScheme::NormalText ).color();
-    const QColor positiveFg = colorScheme.foreground( KColorScheme::PositiveText ).color();
-    const QColor neutralFg = colorScheme.foreground( KColorScheme::NeutralText ).color();
-    const QColor negativeFg = colorScheme.foreground( KColorScheme::NegativeText ).color();
-    
     QPainter p( this );
-    p.setPen( normalFg );
 
-    K3b::Msf docSize;
-    K3b::Msf cdSize;
-    K3b::Msf maxValue;
-    K3b::Msf tolerance;
+    const QPalette::ColorGroup colorGroup = isEnabled() ? QPalette::Normal : QPalette::Disabled;
 
-    docSize = d->doc->length();
-    cdSize = d->cdSize;
-    maxValue = (cdSize > docSize ? cdSize : docSize) + ( 10*60*75 );
-    tolerance = 60*75;
+    const Msf docSize = d->doc->length();
+    const Msf cdSize = d->cdSize;
+    const Msf maxValue = (cdSize > docSize ? cdSize : docSize) + ( 10*60*75 );
+    const Msf tolerance = 60*75;
+
+    QBrush fillBrush;
+    if( docSize <= cdSize - tolerance ) {
+        fillBrush = KColorScheme( colorGroup, KColorScheme::Selection ).background( KColorScheme::PositiveBackground );
+    }
+    else if( docSize > cdSize + tolerance ) {
+        fillBrush = KColorScheme( colorGroup, KColorScheme::Selection ).background( KColorScheme::NegativeBackground );
+    }
+    else {
+        fillBrush = KColorScheme( colorGroup, KColorScheme::Selection ).background( KColorScheme::NeutralBackground );
+    }
+
+    const QPen normalPen = KColorScheme( colorGroup, KColorScheme::Window ).foreground( KColorScheme::NormalText ).color();
+    const QPen fillPen = KColorScheme( colorGroup, KColorScheme::Selection ).foreground( KColorScheme::NormalText ).color();
+
+    QStyleOptionProgressBarV2 sopb;
+    sopb.direction = layoutDirection();
+    sopb.fontMetrics = fontMetrics();
+    sopb.palette = palette();
+    sopb.palette.setBrush( QPalette::Highlight, fillBrush );
+    sopb.rect = rect();
+    sopb.state = isEnabled() ? QStyle::State_Enabled : QStyle::State_None;
+    sopb.minimum = 0;
+    sopb.maximum = maxValue.totalFrames();
+    sopb.progress = docSize.totalFrames();
+    style()->drawControl( QStyle::CE_ProgressBar, &sopb, &p );
+
+    const QRect barRect = style()->subElementRect( QStyle::SE_ProgressBarContents, &sopb );
 
     // so split width() in maxValue pieces
-    double one = (double)rect().width() / (double)maxValue.totalFrames();
-    QRect crect( rect() );
+    double one = (double)barRect.width() / (double)maxValue.totalFrames();
+
+    QRect crect( barRect );
     crect.setWidth( (int)(one*(double)docSize.totalFrames()) );
 
-    p.setClipping(true);
-    p.setClipRect( QStyle::visualRect( layoutDirection(), rect(), crect ) );
-    
-    p.fillRect( QStyle::visualRect( layoutDirection(), rect(), crect ), positiveBg );
-
-    QRect oversizeRect(crect);
-
-    // draw red if docSize > cdSize + tolerance
-    if( docSize > cdSize + tolerance ) {
-        oversizeRect.setLeft( oversizeRect.left() + (int)(one * (cdSize - tolerance).totalFrames()) );
-        QRect negativeRect( oversizeRect.left() - rect().height(), 0, rect().height()*2, rect().height() );
-        QPoint gradientStart( oversizeRect.left() - rect().height(), 0 );
-        QPoint gradientEnd( oversizeRect.left() + rect().height(), 0 );
-        
-        QLinearGradient gradient( QStyle::visualPos( layoutDirection(), rect(), gradientStart ),
-                                  QStyle::visualPos( layoutDirection(), rect(), gradientEnd ) );
-        gradient.setColorAt( 0.1, positiveBg );
-        gradient.setColorAt( 0.5, neutralBg );
-        gradient.setColorAt( 0.9, negativeBg );
-        p.fillRect( QStyle::visualRect( layoutDirection(), rect(), oversizeRect ), negativeBg );
-        p.fillRect( QStyle::visualRect( layoutDirection(), rect(), negativeRect ), gradient );
-        p.setPen( negativeFg );
-        p.drawLine( QStyle::visualPos( layoutDirection(), rect(), oversizeRect.topRight() ),
-                    QStyle::visualPos( layoutDirection(), rect(), oversizeRect.bottomRight() ) );
-    }
-
-    // draw yellow if cdSize - tolerance < docSize
-    else if( docSize > cdSize - tolerance ) {
-        oversizeRect.setLeft( oversizeRect.left() + (int)(one * (cdSize - tolerance).lba()) );
-        QRect neutralRect( oversizeRect.left() - rect().height(), 0, rect().height()*2, rect().height() );
-        QPoint gradientStart( oversizeRect.left() - rect().height(), 0 );
-        QPoint gradientEnd( oversizeRect.left() + rect().height(), 0 );
-        
-        QLinearGradient gradient( QStyle::visualPos( layoutDirection(), rect(), gradientStart ),
-                                  QStyle::visualPos( layoutDirection(), rect(), gradientEnd ) );
-        gradient.setColorAt( 0.1, positiveBg );
-        gradient.setColorAt( 0.9, neutralBg );
-        p.fillRect( QStyle::visualRect( layoutDirection(), rect(), oversizeRect ), neutralBg );
-        p.fillRect( QStyle::visualRect( layoutDirection(), rect(), neutralRect ), gradient );
-        p.setPen( neutralFg );
-        p.drawLine( QStyle::visualPos( layoutDirection(), rect(), oversizeRect.topRight() ),
-                    QStyle::visualPos( layoutDirection(), rect(), oversizeRect.bottomRight() ) );
-    }
-    
-    // draw end column with foreground color to make bar more readable
-    else {
-        p.setPen( positiveFg );
-        p.drawLine( QStyle::visualPos( layoutDirection(), rect(), crect.topRight() ),
-                    QStyle::visualPos( layoutDirection(), rect(), crect.bottomRight() ) );
-    }
-
-    p.setClipping(false);
-
     // ====================================================================================
     // Now the colored bar is painted
     // Continue with the texts
@@ -214,7 +176,7 @@ void K3b::FillStatusDisplayWidget::paintEvent( QPaintEvent* )
     // ====================================================================================
     QString docSizeText;
     if( d->showTime )
-        docSizeText = d->doc->length().toString(false) + " " + i18n("min");
+        docSizeText = i18n("%1 min", d->doc->length().toString(false));
     else
         docSizeText = KIO::convertSize( d->doc->size() );
 
@@ -234,18 +196,13 @@ void K3b::FillStatusDisplayWidget::paintEvent( QPaintEvent* )
                             : KIO::convertSize( (long long)d->doc->size() - cdSize.mode1Bytes() ) );
     // ====================================================================================
 
-    // draw the medium size marker
+    // calculate the medium size marker
     // ====================================================================================
-    int mediumSizeMarkerPos = rect().left() + (int)(one*cdSize.lba());
-    QPoint mediumSizeMarkerFrom( mediumSizeMarkerPos, rect().bottom() );
-    QPoint mediumSizeMarkerTo( mediumSizeMarkerPos, rect().top() + ((rect().bottom()-rect().top())/2) );
-    p.setPen( normalFg );
-    p.drawLine( QStyle::visualPos( layoutDirection(), rect(), mediumSizeMarkerFrom ),
-                QStyle::visualPos( layoutDirection(), rect(), mediumSizeMarkerTo ) );
+    int mediumSizeMarkerPos = barRect.left() + (int)(one*cdSize.lba());
+    QPoint mediumSizeMarkerFrom( mediumSizeMarkerPos, barRect.bottom() );
+    QPoint mediumSizeMarkerTo( mediumSizeMarkerPos, barRect.top() + barRect.height()/2 );
     // ====================================================================================
 
-
-
     // we want to draw the docSizeText centered in the filled area
     // if there is not enough space we just align it left
     // ====================================================================================
@@ -263,14 +220,14 @@ void K3b::FillStatusDisplayWidget::paintEvent( QPaintEvent* )
     }
     // ====================================================================================
 
-    // draw the over size text
+    // calculate the over size text
     // ====================================================================================
-    QFont fnt(font());
-    fnt.setPointSize( qMax( 8, fnt.pointSize()-4 ) );
-    fnt.setBold(false);
+    QFont overSizeFont(font());
+    overSizeFont.setPointSize(qMin(8, overSizeFont.pointSize() - 4));
+    overSizeFont.setBold(false);
 
-    QRect overSizeTextRect( rect() );
-    int overSizeTextLength = QFontMetrics(fnt).width(overSizeText);
+    QRect overSizeTextRect( barRect );
+    int overSizeTextLength = QFontMetrics(overSizeFont).width(overSizeText);
     if( overSizeTextLength + 5 > overSizeTextRect.width() - (int)(one*cdSize.totalFrames()) ) {
         // we don't have enough space on the right, so we paint to the left of the line
         overSizeTextRect.setLeft( (int)(one*cdSize.totalFrames()) - overSizeTextLength - 5 );
@@ -283,13 +240,32 @@ void K3b::FillStatusDisplayWidget::paintEvent( QPaintEvent* )
     if( overSizeTextRect.left() < docSizeTextPos + docSizeTextLength )
         docSizeTextPos = qMax( crect.left() + 5, qMin( overSizeTextRect.left() - docSizeTextLength - 5, mediumSizeMarkerPos - docSizeTextLength - 5 ) );
 
-    QRect docTextRect( rect() );
+    QRect docTextRect( barRect );
     docTextRect.setLeft( docSizeTextPos );
-    p.drawText( QStyle::visualRect( layoutDirection(), rect(), docTextRect ),
-                QStyle::visualAlignment( layoutDirection(), Qt::AlignLeft | Qt::AlignVCenter ), docSizeText );
 
-    p.setFont(fnt);
-    p.drawText( QStyle::visualRect( layoutDirection(), rect(), overSizeTextRect ),
+    // Draw the fill part
+    p.setPen( fillPen );
+    p.setClipRect( QStyle::visualRect( layoutDirection(), barRect, crect ) );
+    p.drawLine( QStyle::visualPos( layoutDirection(), barRect, mediumSizeMarkerFrom ),
+                QStyle::visualPos( layoutDirection(), barRect, mediumSizeMarkerTo ) );
+    p.setFont(overSizeFont);
+    p.drawText( QStyle::visualRect( layoutDirection(), barRect, docTextRect ),
+                QStyle::visualAlignment( layoutDirection(), Qt::AlignLeft | Qt::AlignVCenter ), docSizeText );
+    p.setFont(overSizeFont);
+    p.drawText( QStyle::visualRect( layoutDirection(), barRect, overSizeTextRect ),
+                QStyle::visualAlignment( layoutDirection(), Qt::AlignLeft | Qt::AlignVCenter ), overSizeText );
+
+    // Draw the remain part
+    p.setPen( normalPen );
+    p.setClipRect( QStyle::visualRect( layoutDirection(), barRect,
+                                       QRect( crect.right(), barRect.top(), barRect.width()-crect.width(), barRect.height() ) ) );
+    p.drawLine( QStyle::visualPos( layoutDirection(), barRect, mediumSizeMarkerFrom ),
+                QStyle::visualPos( layoutDirection(), barRect, mediumSizeMarkerTo ) );
+    p.setFont( font() );
+    p.drawText( QStyle::visualRect( layoutDirection(), barRect, docTextRect ),
+                QStyle::visualAlignment( layoutDirection(), Qt::AlignLeft | Qt::AlignVCenter ), docSizeText );
+    p.setFont(overSizeFont);
+    p.drawText( QStyle::visualRect( layoutDirection(), barRect, overSizeTextRect ),
                 QStyle::visualAlignment( layoutDirection(), Qt::AlignLeft | Qt::AlignVCenter ), overSizeText );
     // ====================================================================================
 }
@@ -304,24 +280,24 @@ class K3b::FillStatusDisplay::Private
 {
 public:
     KActionCollection* actionCollection;
-    KAction* actionShowMinutes;
-    KAction* actionShowMegs;
+    QAction* actionShowMinutes;
+    QAction* actionShowMegs;
     QActionGroup* cdSizeGroup;
-    KAction* actionAuto;
-    KAction* action74Min;
-    KAction* action80Min;
-    KAction* action100Min;
-    KAction* actionDvd4_7GB;
-    KAction* actionDvdDoubleLayer;
-    KAction* actionBD25;
-    KAction* actionBD50;
+    QAction* actionAuto;
+    QAction* action74Min;
+    QAction* action80Min;
+    QAction* action100Min;
+    QAction* actionDvd4_7GB;
+    QAction* actionDvdDoubleLayer;
+    QAction* actionBD25;
+    QAction* actionBD50;
 
-    KAction* actionCustomSize;
-    KAction* actionDetermineSize;
-    KAction* actionSaveUserDefaults;
-    KAction* actionLoadUserDefaults;
+    QAction* actionCustomSize;
+    QAction* actionDetermineSize;
+    QAction* actionSaveUserDefaults;
+    QAction* actionLoadUserDefaults;
 
-    KMenu* popup;
+    QMenu* popup;
 
     QToolButton* buttonMenu;
 
@@ -332,7 +308,7 @@ public:
     K3b::Doc* doc;
 
     QTimer updateTimer;
-    
+
     void setCdSize( const K3b::Msf& size );
 };
 
@@ -343,7 +319,7 @@ void K3b::FillStatusDisplay::Private::setCdSize( const K3b::Msf& size )
     if( QAction* checked = cdSizeGroup->checkedAction() ) {
         checked->setChecked( false );
     }
-    
+
     switch( size.totalFrames() ) {
         case MediaSizeCd74Min:
         case 650*512:
@@ -393,21 +369,18 @@ K3b::FillStatusDisplay::FillStatusDisplay( K3b::Doc* doc, QWidget *parent )
     d = new Private;
     d->doc = doc;
 
-    setFrameStyle( Panel | Sunken );
-
     d->displayWidget = new K3b::FillStatusDisplayWidget( doc, this );
-//   d->buttonMenu = new QToolButton( this );
-//   d->buttonMenu->setIconSet( SmallIconSet("media-optical") );
-//   d->buttonMenu->setAutoRaise(true);
-//   d->buttonMenu->setToolTip( i18n("Fill display properties") );
-//   connect( d->buttonMenu, SIGNAL(clicked()), this, SLOT(slotMenuButtonClicked()) );
+    d->buttonMenu = new QToolButton( this );
+    d->buttonMenu->setIcon( QIcon::fromTheme( "configure" ) );
+    d->buttonMenu->setAutoRaise( true );
+    d->buttonMenu->setToolTip( i18n( "Set medium size" ) );
+    connect( d->buttonMenu, SIGNAL(clicked()), this, SLOT(slotMenuButtonClicked()) );
 
-    QGridLayout* layout = new QGridLayout( this );
-    layout->setSpacing(5);
-    layout->setMargin(frameWidth());
-    layout->addWidget( d->displayWidget, 0, 0 );
-    //  layout->addWidget( d->buttonMenu, 0, 1 );
-    layout->setColumnStretch( 0, 1 );
+    QHBoxLayout* layout = new QHBoxLayout( this );
+    layout->setSpacing( frameWidth() );
+    layout->setContentsMargins( frameWidth(), frameWidth(), frameWidth(), frameWidth() );
+    layout->addWidget( d->displayWidget, 1, Qt::AlignVCenter );
+    layout->addWidget( d->buttonMenu );
 
     setupPopupMenu();
 
@@ -430,7 +403,7 @@ void K3b::FillStatusDisplay::setupPopupMenu()
     d->actionCollection = new KActionCollection( this );
 
     // we use a nother popup for the dvd sizes
-    d->popup = new KMenu( this );
+    d->popup = new QMenu( this );
 
     d->actionShowMinutes = K3b::createToggleAction( this, i18n("Minutes"), 0, 0, this, SLOT(showTime()),
                                                     d->actionCollection, "fillstatus_show_minutes" );
@@ -450,9 +423,9 @@ void K3b::FillStatusDisplay::setupPopupMenu()
     d->actionDvdDoubleLayer = K3b::createToggleAction( this, KIO::convertSizeFromKiB((int)(8.0*1024.0*1024.0)),
                                                        0, 0, this, SLOT(slotDvdDoubleLayer()),
                                                        d->actionCollection, "fillstatus_dvd_double_layer" );
-    d->actionBD25 = K3b::createToggleAction( this, KIO::convertSizeFromKiB( 25*1024*1024 ), 0, 0, this, SLOT( slotBD25() ),
+    d->actionBD25 = K3b::createToggleAction( this, KIO::convertSizeFromKiB( 25*1024*1024 ), 0, 0, this, SLOT(slotBD25()),
                                              d->actionCollection, "fillstatus_bd_25" );
-    d->actionBD50 = K3b::createToggleAction( this, KIO::convertSizeFromKiB( 50*1024*1024 ), 0, 0, this, SLOT( slotBD50() ),
+    d->actionBD50 = K3b::createToggleAction( this, KIO::convertSizeFromKiB( 50*1024*1024 ), 0, 0, this, SLOT(slotBD50()),
                                              d->actionCollection, "fillstatus_bd_50" );
 
     d->actionCustomSize = K3b::createAction( this, i18n("Custom..."), 0, 0, this, SLOT(slotCustomSize()),
@@ -482,29 +455,29 @@ void K3b::FillStatusDisplay::setupPopupMenu()
                                                    this, SLOT(slotSaveUserDefaults()),
                                                    d->actionCollection, "save_user_defaults" );
 
-    KAction* dvdSizeInfoAction = K3b::createAction( this, i18n("Why 4.4 instead of 4.7?"), "", 0,
+    QAction* dvdSizeInfoAction = K3b::createAction( this, i18n("Why 4.4 instead of 4.7?"), "", 0,
                                                     this, SLOT(slotWhy44()),
                                                     d->actionCollection, "why_44_gb" );
 
-    d->popup->addTitle( i18n("Show Size In") );
+    d->popup->addSection( i18n("Show Size In") );
     d->popup->addAction( d->actionShowMinutes );
     d->popup->addAction( d->actionShowMegs );
     d->popup->addSeparator();
     d->popup->addAction( d->actionAuto );
     if ( d->doc->supportedMediaTypes() & K3b::Device::MEDIA_CD_ALL ) {
-        d->popup->addTitle( i18n("CD Size") );
+        d->popup->addSection( i18n("CD Size") );
         d->popup->addAction( d->action74Min );
         d->popup->addAction( d->action80Min );
         d->popup->addAction( d->action100Min );
     }
     if ( d->doc->supportedMediaTypes() & K3b::Device::MEDIA_DVD_ALL ) {
-        d->popup->addTitle( i18n("DVD Size") );
+        d->popup->addSection( i18n("DVD Size") );
         d->popup->addAction( dvdSizeInfoAction );
         d->popup->addAction( d->actionDvd4_7GB );
         d->popup->addAction( d->actionDvdDoubleLayer );
     }
     if ( d->doc->supportedMediaTypes() & K3b::Device::MEDIA_BD_ALL ) {
-        d->popup->addTitle( i18n("Blu-ray Size") );
+        d->popup->addSection( i18n("Blu-ray Size") );
         d->popup->addAction( d->actionBD25 );
         d->popup->addAction( d->actionBD50 );
     }
@@ -515,7 +488,7 @@ void K3b::FillStatusDisplay::setupPopupMenu()
     d->popup->addAction( d->actionLoadUserDefaults );
     d->popup->addAction( d->actionSaveUserDefaults );
 
-    connect( d->displayWidget, SIGNAL(contextMenu(const QPoint&)), this, SLOT(slotPopupMenu(const QPoint&)) );
+    connect( d->displayWidget, SIGNAL(contextMenu(QPoint)), this, SLOT(slotPopupMenu(QPoint)) );
 }
 
 
@@ -612,32 +585,37 @@ void K3b::FillStatusDisplay::slotCustomSize()
     QString mbS = i18n("MB");
     QString minS = i18n("min");
 
+    QLocale const locale = QLocale::system();
+
     // we certainly do not have BD- or HD-DVD-only projects
     QString defaultCustom;
     if( d->doc->supportedMediaTypes() & K3b::Device::MEDIA_CD_ALL ) {
         defaultCustom = d->showTime ? QString("74") + minS : QString("650") + mbS;
     }
     else {
-        defaultCustom = KGlobal::locale()->formatNumber(4.4,1) + gbS;
+        defaultCustom = locale.toString(4.4,'g',1) + gbS;
     }
 
-    QRegExp rx( "(\\d+\\" + KGlobal::locale()->decimalSymbol() + "?\\d*)(" + gbS + "|" + mbS + "|" + minS + ")?" );
+    QRegExp rx( QString("(\\d+\\") + locale.decimalPoint() + "?\\d*)(" + gbS + '|' + mbS + '|' + minS + ")?" );
+    QRegExpValidator validator( rx, this );
     bool ok;
-    QString size = KInputDialog::getText( i18n("Custom Size"),
+    QString size = QInputDialog::getText( this,
+                                          i18n("Custom Size"),
                                           i18n("<p>Please specify the size of the medium. Use suffixes <b>GB</b>,<b>MB</b>, "
                                                "and <b>min</b> for <em>gigabytes</em>, <em>megabytes</em>, and <em>minutes</em>"
                                                " respectively."),
+                                          QLineEdit::Normal,
                                           defaultCustom,
-                                          &ok,
-                                          this,
-                                          new QRegExpValidator( rx, this ) );
-    if( ok ) {
+                                          &ok );
+
+    int validatorPos;
+    if( ok && validator.validate( size, validatorPos ) ) {
         // determine size
         if( rx.exactMatch( size ) ) {
             QString valStr = rx.cap(1);
-            if( valStr.endsWith( KGlobal::locale()->decimalSymbol() ) )
-                valStr += "0";
-            double val = KGlobal::locale()->readNumber( valStr, &ok );
+            if( valStr.endsWith( locale.decimalPoint() ) )
+                valStr += '0';
+            double val = locale.toDouble( valStr, &ok );
             if( ok ) {
                 QString s = rx.cap(2);
                 if( s == gbS )
@@ -655,9 +633,9 @@ void K3b::FillStatusDisplay::slotCustomSize()
 
 void K3b::FillStatusDisplay::slotMenuButtonClicked()
 {
-    QSize size = d->popup->sizeHint();
-    slotPopupMenu( d->buttonMenu->mapToGlobal(QPoint(d->buttonMenu->width(), 0)) +
-                   QPoint(-1*size.width(), -1*size.height()) );
+    QRect alignedMenu = style()->alignedRect( layoutDirection(), Qt::AlignRight, d->popup->sizeHint(), d->buttonMenu->frameGeometry() );
+    alignedMenu.moveBottom( d->buttonMenu->frameGeometry().top() - 1 );
+    slotPopupMenu( mapToGlobal( alignedMenu.topLeft() ) );
 }
 
 
@@ -691,7 +669,7 @@ void K3b::FillStatusDisplay::slotDetermineSize()
 void K3b::FillStatusDisplay::slotLoadUserDefaults()
 {
     // load project specific values
-    KConfigGroup c( KGlobal::config(), "default " + d->doc->typeString() + " settings" );
+    KConfigGroup c( KSharedConfig::openConfig(), "default " + d->doc->typeString() + " settings" );
 
     // defaults to megabytes
     d->showTime = c.readEntry( "show minutes", false );
@@ -700,7 +678,7 @@ void K3b::FillStatusDisplay::slotLoadUserDefaults()
     d->actionShowMinutes->setChecked( d->showTime );
 
     long size = c.readEntry( "default media size", 0 );
-    
+
     // Remove check mark from current checked action
     if( QAction* checked = d->cdSizeGroup->checkedAction() ) {
         checked->setChecked( false );
@@ -832,7 +810,7 @@ void K3b::FillStatusDisplay::slotMediumChanged( K3b::Device::Device* )
 void K3b::FillStatusDisplay::slotSaveUserDefaults()
 {
     // save project specific values
-    KConfigGroup c( KGlobal::config(), "default " + d->doc->typeString() + " settings" );
+    KConfigGroup c( KSharedConfig::openConfig(), "default " + d->doc->typeString() + " settings" );
 
     c.writeEntry( "show minutes", d->showTime );
     c.writeEntry( "default media size", d->actionAuto->isChecked() ? 0 : d->displayWidget->cdSize().lba() );
@@ -871,9 +849,9 @@ bool K3b::FillStatusDisplay::event( QEvent* event )
 
         QToolTip::showText( he->globalPos(),
                             KIO::convertSize( d->doc->size() ) +
-                            " (" + KGlobal::locale()->formatNumber( d->doc->size(), 0 ) + "), " +
-                            d->doc->length().toString(false) + " " + i18n("min") +
-                            " (" + i18n("Right click for media sizes") + ")");
+                            " (" + QLocale::system().toString( d->doc->size() ) + "), " +
+                            i18n("%1 min", d->doc->length().toString(false)) +
+                            " (" + i18n("Right click for media sizes") + ')');
 
         event->accept();
 
@@ -883,4 +861,4 @@ bool K3b::FillStatusDisplay::event( QEvent* event )
     return QFrame::event( event );
 }
 
-#include "k3bfillstatusdisplay.moc"
+
